import sqlite3
import os

DB_PATH = os.path.join(
    os.path.dirname(__file__),
    '../../cache/db/config.db'
)

class ConfigDB:
    def __init__(self, db_path=DB_PATH):
        self.db_path = db_path
        self.conn = sqlite3.connect(self.db_path)
        self.create_tables()

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        self.close()

    def create_tables(self):
        """
        Creates the 'github_keys' table if not already present.
        """
        cursor = self.conn.cursor()
        cursor.execute('''
            CREATE TABLE IF NOT EXISTS github_keys (
                id INTEGER PRIMARY KEY AUTOINCREMENT,
                github_key TEXT NOT NULL
            )
        ''')
        self.conn.commit()

    def add_github_key(self, key_value):
        """
        Inserts a new GitHub key into the github_keys table.
        """
        cursor = self.conn.cursor()
        cursor.execute("INSERT INTO github_keys (github_key) VALUES (?)", (key_value,))
        self.conn.commit()

    def list_github_keys(self):
        """
        Returns all GitHub keys without their IDs (plain list of strings).
        """
        cursor = self.conn.cursor()
        cursor.execute("SELECT github_key FROM github_keys")
        rows = cursor.fetchall()
        return [row[0] for row in rows]

    def list_github_keys_with_ids(self):
        """
        Returns a list of (id, github_key) tuples so we can edit/delete by ID.
        """
        cursor = self.conn.cursor()
        cursor.execute("SELECT id, github_key FROM github_keys")
        return cursor.fetchall()

    def update_github_key_by_id(self, row_id, new_key):
        """
        Updates the github_keys row with a new key using the row's id.
        """
        cursor = self.conn.cursor()
        cursor.execute("UPDATE github_keys SET github_key = ? WHERE id = ?", (new_key, row_id))
        self.conn.commit()

    def delete_github_key_by_id(self, row_id):
        """
        Deletes the row from github_keys based on the provided id.
        """
        cursor = self.conn.cursor()
        cursor.execute("DELETE FROM github_keys WHERE id = ?", (row_id,))
        self.conn.commit()

    def close(self):
        self.conn.close()